Package: plasmut
Type: Package
Title: Stratifying mutations observed in cell-free DNA and white blood
        cells as germline, hematopoietic, or somatic
Version: 1.11.0
Authors@R: 
  c(person(given = "Adith",
           family = "Arun",
           role = c("aut", "cre"),
           email = "adith.3.arun@gmail.com"),
    person(given = "Robert",
           family = "Scharpf",
           role = "aut"))
Description: A Bayesian method for quantifying the liklihood that a given plasma mutation arises from clonal hematopoesis or the underlying tumor. It requires sequencing data of the mutation in plasma and white blood cells with the number of distinct and mutant reads in both tissues. We implement a Monte Carlo importance sampling method to assess the likelihood that a mutation arises from the tumor relative to non-tumor origin.
License: Artistic-2.0
Encoding: UTF-8
biocViews: Bayesian, SomaticMutation, GermlineMutation, Sequencing
RoxygenNote: 7.2.3
Imports: tibble, stats, dplyr
Depends: R (>= 4.3.0)
Suggests: knitr, rmarkdown, tidyverse, ggrepel, magrittr, qpdf,
        BiocStyle, biocViews, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/plasmut
git_branch: devel
git_last_commit: 7b0b25f
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:23:06 UTC; biocbuild
Author: Adith Arun [aut, cre],
  Robert Scharpf [aut]
Maintainer: Adith Arun <adith.3.arun@gmail.com>
