#' Bayesian models for estimating the origin of a sequenced DNA fragment
#'
#' The plasmut package provides a Bayesian importance sampling based approach 
#' to estimate the liklihood of a mutation arising from clonal hematopoiesis
#' or tumor
#' @docType package
#' @name plasmut
#' @import tibble
#' @importFrom dplyr filter bind_rows
#' @importFrom stats rbeta rbinom dbeta dbinom setNames
NULL