#' This data is an example dataset to show how to use the package
#'
#'
#' A cohort of metastatic colorectal cancer patients whose plasma and buffy 
#' coat were sequenced as part of the CAIRO5 trial. 
#' The cohort and analyses are described here: 
#' \url{https://pubmed.ncbi.nlm.nih.gov/36534496/}
#'
#'
#'
#' @docType data
#' @name crcseq
#' @return An example DNA sequencing dataset of matched plasma 
#' and wbc colorectal cancer samples
#' crcseq
NULL










